#!/usr/bin/env ambari-python-wrap
"""
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import imp
import os
import traceback
import xml.etree.ElementTree as ET

SCRIPT_DIR = os.path.dirname(os.path.abspath(__file__))
STACKS_DIR = os.path.join(SCRIPT_DIR, '../../../../')
PARENT_FILE = os.path.join(STACKS_DIR, 'service_advisor.py')

try:
    with open(PARENT_FILE, 'rb') as fp:
        service_advisor = imp.load_module('service_advisor', fp, PARENT_FILE, ('.py', 'rb', imp.PY_SOURCE))
except Exception as e:
    traceback.print_exc()
    print "Failed to load parent"


class HDP24TESTServiceAdvisor(service_advisor.ServiceAdvisor):

    def __init__(self, *args, **kwargs):
        self.as_super = super(HDP24TESTServiceAdvisor, self)
        self.as_super.__init__(*args, **kwargs)

    def getServiceConfigurationRecommendations(self, configurations, clusterData, services, hosts):

        print "=============> In TEST service advisor's  getServiceConfigurationRecommendations method"
        if "test-env" in services["configurations"]:
            if 'forced-configurations' not in services:
                services["forced-configurations"] = []

            old_properties = services["configurations"]["test-env"]["properties"]
            putTestEnvProperty = self.putProperty(configurations, "test-env", services)

            new_properties = {}
            tree = ET.parse(os.path.join(SCRIPT_DIR, 'configuration/test-env.xml'))
            for el in tree.findall('.//property'):
                new_properties[el.find('.//name').text]=el.find('.//value').text

            # Add new properties
            for property, value in new_properties.iteritems():
                if property not in old_properties:
                    services["forced-configurations"].append({"type": "test-env", "name": property})
                    putTestEnvProperty(property, value)
